SizeSnappingModel constructor

const SizeSnappingModel(
  1. Set<double> sizes
)

Constructs a SizeSnappingModel with the specified sizes.

  • sizes: A set of pixel values representing snapping positions. These values should typically be greater than or equal to 0.0 and less than or equal to the maximum pixel height of the sheet's viewport.

Usage Example:

// Define snapping positions at 100px, 300px, and 600px from the bottom of the viewport.
final snappingModel = SizeSnappingModel({100.0, 300.0, 600.0});

Implementation

const SizeSnappingModel(this.sizes);