sizes property

Set<double> sizes
final

A set of pixel sizes which are defining the snapping positions. Each position is measured from the bottom of the viewport upwards.

Implementation

final Set<double> sizes;