SizeSnappingModel class final
Snapping model that calculates snapping positions based on fixed pixel positions.
This model defines snapping offsets as absolute positions relative to the bottom of the viewport, allowing for precise snapping states based on the pixel size of the sheet. It is used with the sheet's SnappingBehavior to implement fixed-size snapping logic.
- Inheritance
-
- Object
- SnappingModel
- SizeSnappingModel
Constructors
-
SizeSnappingModel(Set<
double> sizes) -
Constructs a SizeSnappingModel with the specified
sizes.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sizes
→ Set<
double> -
A set of pixel sizes which are defining the snapping positions.
Each position is measured from the bottom of the viewport upwards.
final
Methods
-
getOffsets<
T> (MultiStateSheetExtent< T> extent) → SplayTreeSet<double> -
Calculates snapping offsets based on sized pixel positions.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited