sheetify library
Classes
- ComponentsSnappingBehavior
- A snapping behavior that calculates snapping offsets based on component descriptions.
- ComponentsSnappingModel
- Represents a snapping model for calculating snapping positions and states based on the sizes of Widgets in a MultiStateSheet. It generates snapping positions using the provided descriptions of components.
- DraggerContainer
- A StatelessWidget that provides a dragger inside a container widget.
- FixedHeightModel
- Model used to calculate the fixed offset of the ToggleSheet
- FourStateMapper
-
State handler for pages that only have
4different states. - FractionHeightModel
- Model used to calculate the fixed offset of the ToggleSheet
-
FractionSnappingBehavior<
StateType> - Controls the snapping behavior of a sheet based on fractions of its bounding box.
- FractionSnappingModel
- Snapping model that calculates snapping positions based on fraction of the sheet's viewport.
- IntStateMapper
- A generic state handler for cases where a page can use any number of states.
- KeyboardInsets
- Main class to access keyboard insets and state.
- MultiSnappingBehavior
- A snapping behavior that combines multiple SnappingModel instances to calculate snapping offsets and states.
-
MultiStateSheet<
StateType> - A customizable and animated multi snap-state sheet widget.
-
MultiStateSheetBuilder<
StateType> - A widget that builds a sheet component based on a given builder function.
-
MultiStateSheetController<
StateType> - Controller for managing the state and behavior of a MultiStateSheet.
-
MultiStateSheetExtent<
StateType> - A class that represents the extent (size) of a multi state sheet.
-
MultiStateSheetNotifier<
StateType> - An InheritedWidget that notifies its descendants about changes in the multi-state sheet's state.
- OffsetHeightModel
- Model used to calculate the fixed offset of the ToggleSheet
- OffsetSnappingModel
- Snapping model that calculates snapping positions based on fixed pixel positions.
- PersistentSafeArea
- A widget that insets its child by the current safe area padding (such as the home indicator or navigation bar) which stays stable during keyboard animations.
- PersistentSafeAreaBottom
- Provides access to the system's bottom safe area (home indicator or navigation bar).
-
SheetAnimatedStatefulWidget<
StateType> - A base class for creating sheet's state aware stateful animated widgets.
-
SheetAnimatedWidget<
StateType> - A base class for creating sheet's state aware stateless animated widget.
-
SheetStateMapper<
T> - Base interface to create new state handlers for sheet pages.
-
SheetStateNotifierStatefulWidget<
StateType> - A base class for creating sheet's state aware stateful animated widgets.
-
SheetValueNotifierWidget<
StateType> - A base class for creating sheet's state aware stateless animated widgets based on ValueNotifier.
- SheetWidgetSizes
- A utility class that provides constants related to sizing of sheet widgets.
- SizeSnappingBehavior
-
Snapping behavior which is using
sheet sizesin pixels to calculate snapping offsets and it's states. - SizeSnappingModel
- Snapping model that calculates snapping positions based on fixed pixel positions.
- SnapComponent
- Abstract base class for snap components, providing a contract for calculating the size of components within a snapping behavior.
- SnapComponentAtFraction
- Represents a snap component that stops at a specified fraction position.
- SnapComponentAtPosition
- Represents a snap component that stops at a specific pixel position in the MultiStateSheet.
- SnapComponentMap
- A wrapper around a snap component that applies a mapping function to its size.
- SnapComponentMerge
- A snap component that merges the sizes of two components using a custom merge function.
- SnapComponentSize
- Represents a snap component with a specified size based on a multiplier of the component's initial size.
- SnapComponentWithOffset
- Represents a snap component with a specified size and an additional pixel offset.
- SnapComponentWithOffsetFraction
- Represents a snap component with a size and an fraction, where the fraction is a fraction of viewport.
- SnappingBehavior
- Defines the snapping behavior for a sheet during scrolling and dragging.
- SnappingModel
- Base class for all MultiStateSheet snapping models used in conjunction with SnappingBehavior.
-
StatefulSheetDelegate<
T> - A sealed class that represents a delegate for the MultiStateSheet.
-
StatefulSheetDelegateFunction<
T, S> - A delegate that holds a function which uses the MultiStateSheetController to compute a dynamic value.
-
StatefulSheetDelegateValue<
T> - A delegate that holds a static value.
- ThreeStateMapper
-
State handler for pages that only have
3different states. - ToggleSheet
- ToggleSheetController
- A controller for managing the state of a toggle sheet.
-
ToggleSheetDelegate<
T> - A sealed class that represents a delegate for the sheet.
-
ToggleSheetDelegateFunction<
T> - A delegate that dynamically computes a value based on the ToggleSheetController state.
-
ToggleSheetDelegateValue<
T> - A delegate that always returns a constant, static value.
- ToggleSheetExtent
- A class that represents the extent (size) of a toggle sheet.
- ToggleSheetHeightModel
- Model used to calculate the fixed offset of the ToggleSheet
Enums
- Components
- Enum representing the various components of a MultiStateSheet layout.
- FourStateSheet
- ThreeStateSheet
- ToggleSheetStart
- Describes the behavior of the sheet appearance for the initial state.
Typedefs
-
MultiStateSheetAnimatedWidgetBuilder<
StateType> = Widget Function(BuildContext context, StateType state, double interpolation, Widget? child) - A function type used to build sheet's state aware animated widgets.
- OffsetMap = double Function(double offset)
- OffsetMerge = double Function(double a, double b)
-
StatefulFunctionDelegate<
T, S> = T? Function(MultiStateSheetController< S> controller) - ToggleSheetOnCloseCallback = void Function(ToggleSheetController controller)